@@ -4,9 +4,6 @@ Generate ROC, PR, Correlation and score to Recall/Pricision/Fallout curves.
 """
 from __future__ import division
 from __future__ import print_function
-from builtins import str
-from builtins import zip
-
 __author__ = 'zf'
 
 import sys, os, time
